<?php

namespace Drupal\acquia_search\EventSubscriber\AcquiaSubscriptionData;

use Drupal\acquia_connector\AcquiaConnectorEvents;
use Drupal\acquia_connector\Event\AcquiaSubscriptionDataEvent;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleExtensionList;
use Drupal\search_api\Entity\Index;
use Drupal\search_api\Entity\Server;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Add metadata from Acquia Search to Acquia Connector's subscription.
 */
class AcquiaSearchData implements EventSubscriberInterface {

  /**
   * Acquia Search Module Version.
   *
   * @var string
   */
  protected $moduleVersion;

  /**
   * Add metadata constructor
   *
   * @param \Drupal\Core\Extension\ModuleExtensionList $module_extension_list
   *   Module Extension List
   */
  public function __construct(ModuleExtensionList $module_extension_list) {
    $info = $module_extension_list->getExtensionInfo('acquia_search');
    // Send the version, or at least the core compatibility as a fallback.
    $this->moduleVersion = (string) ($info['version'] ?? \Drupal::VERSION);
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[AcquiaConnectorEvents::GET_SUBSCRIPTION][] = ['onGetSubscriptionData', 100];
    return $events;
  }

  /**
   * Gets a prebuilt Settings object from Drupal's settings file.
   *
   * @param \Drupal\acquia_connector\Event\AcquiaSubscriptionDataEvent $event
   *   The dispatched event.
   *
   * @see \Drupal\acquia_connector\Settings
   */
  public function onGetSubscriptionData(AcquiaSubscriptionDataEvent $event) {
    $config = $event->getConfig('acquia_search.settings');
    $subscription_data = $event->getData();

    $subscription_data['acquia_search'] = $config->getRawData();;
    // When updating to v3, the api_host may not exist, manually put it in.
    if (!isset($subscription_data['acquia_search']['api_host'])) {
      $subscription_data['acquia_search']['api_host'] = 'https://api.sr-prod02.acquia.com';
    }

    $subscription_data['acquia_search']['module_version'] = $this->moduleVersion;

    // Add Acquia Search module version to subscription data.
    $event->setData($subscription_data);
  }

}
