<?php

namespace Drupal\acquia_search\EventSubscriber\PossibleCores;

use Drupal\acquia_connector\Subscription;
use Drupal\Core\Site\Settings;
use Drupal\search_api\SearchApiException;
use Drupal\search_api_solr\Event\PreQueryEvent;
use Drupal\search_api_solr\Event\SearchApiSolrEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Gets the ContentHub Server settings from Drupal's settings.
 */
class EdisMax implements EventSubscriberInterface {

  /**
   * Drupal Settings.
   *
   * @var \Drupal\Core\Site\Settings
   */
  protected $settings;

  /**
   * Acquia subscription service.
   *
   * @var \Drupal\acquia_connector\Subscription
   */
  protected $subscription;

  /**
   * Get Possible Cores from Cloud Constructor
   *
   * @param \Drupal\Core\Site\Settings $settings
   *   Core Settings
   */
  public function __construct(Settings $settings, Subscription $subscription) {
    $this->settings = $settings;
    $this->subscription = $subscription;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      SearchApiSolrEvents::PRE_QUERY => 'preQuery',
    ];
  }

  /**
   * Add EdisMax for Acquia Solr Queries
   *
   * @param \Drupal\acquia_search\Event\AcquiaPossibleCoresEvent $event
   *   The dispatched event.
   *
   * @see \Drupal\acquia_connector\Settings
   */
  public function preQuery(PreQueryEvent $event) {
    $solarium_query = $event->getSolariumQuery();
    $handler = $solarium_query->getHandler();
    $search_index = $event->getSearchApiQuery()->getIndex();
    try {
      $server = $search_index->getServerInstance();
    }
    catch (SearchApiException $exception) {
      return;
    }

    if (empty($server)) {
      return;
    }

    $backend_config = $server->getBackendConfig();
    if (!(!empty($backend_config['connector']) && $backend_config['connector'] === 'solr_acquia_connector')) {
      return;
    }

    if ('select' === $handler) {
      $use_edismax = $search_index->getThirdPartySetting(
        'acquia_search',
        'use_edismax',
        TRUE
      );
      if ($use_edismax) {
        $solarium_query->addParam('defType', 'edismax');
      }
    }
  }
}
